# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_cms_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_cms_pb2 as protos_dot_ydb__cms__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ydb_cms_v1.proto',
  package='Ydb.Cms.V1',
  syntax='proto3',
  serialized_options=b'\n\017tech.ydb.cms.v1Z2github.com/ydb-platform/ydb-go-genproto/Ydb_Cms_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10ydb_cms_v1.proto\x12\nYdb.Cms.V1\x1a\x14protos/ydb_cms.proto2\x9c\x04\n\nCmsService\x12Q\n\x0e\x43reateDatabase\x12\x1e.Ydb.Cms.CreateDatabaseRequest\x1a\x1f.Ydb.Cms.CreateDatabaseResponse\x12Z\n\x11GetDatabaseStatus\x12!.Ydb.Cms.GetDatabaseStatusRequest\x1a\".Ydb.Cms.GetDatabaseStatusResponse\x12N\n\rAlterDatabase\x12\x1d.Ydb.Cms.AlterDatabaseRequest\x1a\x1e.Ydb.Cms.AlterDatabaseResponse\x12N\n\rListDatabases\x12\x1d.Ydb.Cms.ListDatabasesRequest\x1a\x1e.Ydb.Cms.ListDatabasesResponse\x12Q\n\x0eRemoveDatabase\x12\x1e.Ydb.Cms.RemoveDatabaseRequest\x1a\x1f.Ydb.Cms.RemoveDatabaseResponse\x12l\n\x17\x44\x65scribeDatabaseOptions\x12\'.Ydb.Cms.DescribeDatabaseOptionsRequest\x1a(.Ydb.Cms.DescribeDatabaseOptionsResponseBE\n\x0ftech.ydb.cms.v1Z2github.com/ydb-platform/ydb-go-genproto/Ydb_Cms_V1b\x06proto3'
  ,
  dependencies=[protos_dot_ydb__cms__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_CMSSERVICE = _descriptor.ServiceDescriptor(
  name='CmsService',
  full_name='Ydb.Cms.V1.CmsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=55,
  serialized_end=595,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateDatabase',
    full_name='Ydb.Cms.V1.CmsService.CreateDatabase',
    index=0,
    containing_service=None,
    input_type=protos_dot_ydb__cms__pb2._CREATEDATABASEREQUEST,
    output_type=protos_dot_ydb__cms__pb2._CREATEDATABASERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDatabaseStatus',
    full_name='Ydb.Cms.V1.CmsService.GetDatabaseStatus',
    index=1,
    containing_service=None,
    input_type=protos_dot_ydb__cms__pb2._GETDATABASESTATUSREQUEST,
    output_type=protos_dot_ydb__cms__pb2._GETDATABASESTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AlterDatabase',
    full_name='Ydb.Cms.V1.CmsService.AlterDatabase',
    index=2,
    containing_service=None,
    input_type=protos_dot_ydb__cms__pb2._ALTERDATABASEREQUEST,
    output_type=protos_dot_ydb__cms__pb2._ALTERDATABASERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDatabases',
    full_name='Ydb.Cms.V1.CmsService.ListDatabases',
    index=3,
    containing_service=None,
    input_type=protos_dot_ydb__cms__pb2._LISTDATABASESREQUEST,
    output_type=protos_dot_ydb__cms__pb2._LISTDATABASESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveDatabase',
    full_name='Ydb.Cms.V1.CmsService.RemoveDatabase',
    index=4,
    containing_service=None,
    input_type=protos_dot_ydb__cms__pb2._REMOVEDATABASEREQUEST,
    output_type=protos_dot_ydb__cms__pb2._REMOVEDATABASERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeDatabaseOptions',
    full_name='Ydb.Cms.V1.CmsService.DescribeDatabaseOptions',
    index=5,
    containing_service=None,
    input_type=protos_dot_ydb__cms__pb2._DESCRIBEDATABASEOPTIONSREQUEST,
    output_type=protos_dot_ydb__cms__pb2._DESCRIBEDATABASEOPTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CMSSERVICE)

DESCRIPTOR.services_by_name['CmsService'] = _CMSSERVICE

# @@protoc_insertion_point(module_scope)
