# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v4.protos import ydb_common_pb2 as protos_dot_ydb__common__pb2
from ydb._grpc.v4.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v4.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v4.protos import ydb_query_stats_pb2 as protos_dot_ydb__query__stats__pb2
from ydb._grpc.v4.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v4.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2
from ydb._grpc.v4.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v4.protos import ydb_formats_pb2 as protos_dot_ydb__formats__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16protos/ydb_table.proto\x12\tYdb.Table\x1a#protos/annotations/validation.proto\x1a\x17protos/ydb_common.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1cprotos/ydb_query_stats.proto\x1a\x16protos/ydb_value.proto\x1a\x17protos/ydb_scheme.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x18protos/ydb_formats.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"Q\n\x14\x43reateSessionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15\x43reateSessionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\")\n\x13\x43reateSessionResult\x12\x12\n\nsession_id\x18\x01 \x01(\t\"e\n\x14\x44\x65leteSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15\x44\x65leteSessionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\r\n\x0bGlobalIndex\"\x12\n\x10GlobalAsyncIndex\"\xba\x01\n\nTableIndex\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rindex_columns\x18\x02 \x03(\t\x12.\n\x0cglobal_index\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.GlobalIndexH\x00\x12\x39\n\x12global_async_index\x18\x04 \x01(\x0b\x32\x1b.Ydb.Table.GlobalAsyncIndexH\x00\x12\x14\n\x0c\x64\x61ta_columns\x18\x05 \x03(\tB\x06\n\x04type\"\xdb\x02\n\x15TableIndexDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rindex_columns\x18\x02 \x03(\t\x12.\n\x0cglobal_index\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.GlobalIndexH\x00\x12\x39\n\x12global_async_index\x18\x05 \x01(\x0b\x32\x1b.Ydb.Table.GlobalAsyncIndexH\x00\x12\x37\n\x06status\x18\x04 \x01(\x0e\x32\'.Ydb.Table.TableIndexDescription.Status\x12\x14\n\x0c\x64\x61ta_columns\x18\x06 \x03(\t\x12\x12\n\nsize_bytes\x18\x07 \x01(\x04\"G\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTATUS_READY\x10\x01\x12\x13\n\x0fSTATUS_BUILDING\x10\x02\x42\x06\n\x04type\"\xdd\x01\n\x0fIndexBuildState\"\xc9\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATE_PREPARING\x10\x01\x12\x1a\n\x16STATE_TRANSFERING_DATA\x10\x02\x12\x12\n\x0eSTATE_APPLYING\x10\x03\x12\x0e\n\nSTATE_DONE\x10\x04\x12\x16\n\x12STATE_CANCELLATION\x10\x05\x12\x13\n\x0fSTATE_CANCELLED\x10\x06\x12\x13\n\x0fSTATE_REJECTION\x10\x07\x12\x12\n\x0eSTATE_REJECTED\x10\x08\"K\n\x15IndexBuildDescription\x12\x0c\n\x04path\x18\x01 \x01(\t\x12$\n\x05index\x18\x02 \x01(\x0b\x32\x15.Ydb.Table.TableIndex\"\x8e\x01\n\x12IndexBuildMetadata\x12\x35\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32 .Ydb.Table.IndexBuildDescription\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .Ydb.Table.IndexBuildState.State\x12\x10\n\x08progress\x18\x03 \x01(\x02\"\x9a\x01\n\x0e\x43hangefeedMode\"\x87\x01\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODE_KEYS_ONLY\x10\x01\x12\x10\n\x0cMODE_UPDATES\x10\x02\x12\x12\n\x0eMODE_NEW_IMAGE\x10\x03\x12\x12\n\x0eMODE_OLD_IMAGE\x10\x04\x12\x1b\n\x17MODE_NEW_AND_OLD_IMAGES\x10\x05\"E\n\x10\x43hangefeedFormat\"1\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x46ORMAT_JSON\x10\x01\"\xcd\x01\n\nChangefeed\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x04mode\x18\x02 \x01(\x0e\x32\x1e.Ydb.Table.ChangefeedMode.Mode\x12\x32\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\".Ydb.Table.ChangefeedFormat.Format\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1a\n\x12virtual_timestamps\x18\x05 \x01(\x08\"\xa1\x02\n\x15\x43hangefeedDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x04mode\x18\x02 \x01(\x0e\x32\x1e.Ydb.Table.ChangefeedMode.Mode\x12\x32\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\".Ydb.Table.ChangefeedFormat.Format\x12\x35\n\x05state\x18\x04 \x01(\x0e\x32&.Ydb.Table.ChangefeedDescription.State\x12\x1a\n\x12virtual_timestamps\x18\x05 \x01(\x08\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_ENABLED\x10\x01\x12\x12\n\x0eSTATE_DISABLED\x10\x02\"\x1c\n\x0bStoragePool\x12\r\n\x05media\x18\x01 \x01(\t\"\xaa\x02\n\rStoragePolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12&\n\x06syslog\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12#\n\x03log\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12$\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x05 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12/\n\x0ekeep_in_memory\x18\x06 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x36\n\x0f\x63olumn_families\x18\x07 \x03(\x0b\x32\x1d.Ydb.Table.ColumnFamilyPolicy\"\xb1\x02\n\x12\x43olumnFamilyPolicy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12/\n\x0ekeep_in_memory\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12>\n\x0b\x63ompression\x18\x05 \x01(\x0e\x32).Ydb.Table.ColumnFamilyPolicy.Compression\"L\n\x0b\x43ompression\x12\x1b\n\x17\x43OMPRESSION_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNCOMPRESSED\x10\x01\x12\x0e\n\nCOMPRESSED\x10\x02\"\'\n\x10\x43ompactionPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\";\n\x12\x45xplicitPartitions\x12%\n\x0csplit_points\x18\x01 \x03(\x0b\x32\x0f.Ydb.TypedValue\";\n\x0ePartitionStats\x12\x15\n\rrows_estimate\x18\x01 \x01(\x04\x12\x12\n\nstore_size\x18\x02 \x01(\x04\"\xe9\x01\n\nTableStats\x12\x32\n\x0fpartition_stats\x18\x01 \x03(\x0b\x32\x19.Ydb.Table.PartitionStats\x12\x15\n\rrows_estimate\x18\x02 \x01(\x04\x12\x12\n\nstore_size\x18\x03 \x01(\x04\x12\x12\n\npartitions\x18\x04 \x01(\x04\x12\x31\n\rcreation_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11modification_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xdc\x02\n\x12PartitioningPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12O\n\x11\x61uto_partitioning\x18\x02 \x01(\x0e\x32\x34.Ydb.Table.PartitioningPolicy.AutoPartitioningPolicy\x12\x1c\n\x12uniform_partitions\x18\x03 \x01(\x04H\x00\x12<\n\x13\x65xplicit_partitions\x18\x04 \x01(\x0b\x32\x1d.Ydb.Table.ExplicitPartitionsH\x00\"v\n\x16\x41utoPartitioningPolicy\x12(\n$AUTO_PARTITIONING_POLICY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x0e\n\nAUTO_SPLIT\x10\x02\x12\x14\n\x10\x41UTO_SPLIT_MERGE\x10\x03\x42\x0c\n\npartitions\"&\n\x0f\x45xecutionPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\"\xb1\x01\n\x11ReplicationPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12\x16\n\x0ereplicas_count\x18\x02 \x01(\r\x12=\n\x1c\x63reate_per_availability_zone\x18\x03 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x30\n\x0f\x61llow_promotion\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"$\n\rCachingPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\"\xeb\x02\n\x0cTableProfile\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12\x30\n\x0estorage_policy\x18\x02 \x01(\x0b\x32\x18.Ydb.Table.StoragePolicy\x12\x36\n\x11\x63ompaction_policy\x18\x03 \x01(\x0b\x32\x1b.Ydb.Table.CompactionPolicy\x12:\n\x13partitioning_policy\x18\x04 \x01(\x0b\x32\x1d.Ydb.Table.PartitioningPolicy\x12\x34\n\x10\x65xecution_policy\x18\x05 \x01(\x0b\x32\x1a.Ydb.Table.ExecutionPolicy\x12\x38\n\x12replication_policy\x18\x06 \x01(\x0b\x32\x1c.Ydb.Table.ReplicationPolicy\x12\x30\n\x0e\x63\x61\x63hing_policy\x18\x07 \x01(\x0b\x32\x18.Ydb.Table.CachingPolicy\"C\n\nColumnMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x04type\x18\x02 \x01(\x0b\x32\t.Ydb.Type\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\"O\n\x1a\x44\x61teTypeColumnModeSettings\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpire_after_seconds\x18\x02 \x01(\r\"\x8e\x02\n\x1fValueSinceUnixEpochModeSettings\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x44\n\x0b\x63olumn_unit\x18\x02 \x01(\x0e\x32/.Ydb.Table.ValueSinceUnixEpochModeSettings.Unit\x12\x1c\n\x14\x65xpire_after_seconds\x18\x03 \x01(\r\"r\n\x04Unit\x12\x14\n\x10UNIT_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNIT_SECONDS\x10\x01\x12\x15\n\x11UNIT_MILLISECONDS\x10\x02\x12\x15\n\x11UNIT_MICROSECONDS\x10\x03\x12\x14\n\x10UNIT_NANOSECONDS\x10\x04\"\xc4\x01\n\x0bTtlSettings\x12\x41\n\x10\x64\x61te_type_column\x18\x01 \x01(\x0b\x32%.Ydb.Table.DateTypeColumnModeSettingsH\x00\x12L\n\x16value_since_unix_epoch\x18\x02 \x01(\x0b\x32*.Ydb.Table.ValueSinceUnixEpochModeSettingsH\x00\x12\x1c\n\x14run_interval_seconds\x18\x03 \x01(\rB\x06\n\x04mode\"\xda\x01\n\x0fStorageSettings\x12\x32\n\x12tablet_commit_log0\x18\x01 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x32\n\x12tablet_commit_log1\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x04 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x35\n\x14store_external_blobs\x18\x05 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"\x84\x02\n\x0c\x43olumnFamily\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x38\n\x0b\x63ompression\x18\x03 \x01(\x0e\x32#.Ydb.Table.ColumnFamily.Compression\x12/\n\x0ekeep_in_memory\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"U\n\x0b\x43ompression\x12\x1b\n\x17\x43OMPRESSION_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OMPRESSION_NONE\x10\x01\x12\x13\n\x0f\x43OMPRESSION_LZ4\x10\x02\"\xf7\x01\n\x14PartitioningSettings\x12\x14\n\x0cpartition_by\x18\x01 \x03(\t\x12\x35\n\x14partitioning_by_size\x18\x02 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x19\n\x11partition_size_mb\x18\x03 \x01(\x04\x12\x35\n\x14partitioning_by_load\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x1c\n\x14min_partitions_count\x18\x06 \x01(\x04\x12\x1c\n\x14max_partitions_count\x18\x07 \x01(\x04J\x04\x08\x05\x10\x06\"C\n\x16\x41zReadReplicasSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13read_replicas_count\x18\x02 \x01(\x04\"_\n\x17\x43lusterReplicasSettings\x12\x44\n\x19\x61z_read_replicas_settings\x18\x02 \x03(\x0b\x32!.Ydb.Table.AzReadReplicasSettings\"t\n\x14ReadReplicasSettings\x12$\n\x1aper_az_read_replicas_count\x18\x01 \x01(\x04H\x00\x12$\n\x1a\x61ny_az_read_replicas_count\x18\x02 \x01(\x04H\x00\x42\n\n\x08settingsJ\x04\x08\x03\x10\x04\"\xdc\x06\n\x12\x43reateTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12&\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x04 \x03(\t\x12(\n\x07profile\x18\x05 \x01(\x0b\x32\x17.Ydb.Table.TableProfile\x12\x39\n\x10operation_params\x18\x06 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12&\n\x07indexes\x18\x07 \x03(\x0b\x32\x15.Ydb.Table.TableIndex\x12,\n\x0cttl_settings\x18\x08 \x01(\x0b\x32\x16.Ydb.Table.TtlSettings\x12\x34\n\x10storage_settings\x18\t \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x30\n\x0f\x63olumn_families\x18\n \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12Z\n\nattributes\x18\x0b \x03(\x0b\x32-.Ydb.Table.CreateTableRequest.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x12\x19\n\x11\x63ompaction_policy\x18\x0c \x01(\t\x12\x1c\n\x12uniform_partitions\x18\r \x01(\x04H\x00\x12:\n\x11partition_at_keys\x18\x0e \x01(\x0b\x32\x1d.Ydb.Table.ExplicitPartitionsH\x00\x12>\n\x15partitioning_settings\x18\x0f \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x31\n\x10key_bloom_filter\x18\x10 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12?\n\x16read_replicas_settings\x18\x11 \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\npartitions\"C\n\x13\x43reateTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"u\n\x10\x44ropTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParamsJ\x04\x08\x03\x10\x04\"A\n\x11\x44ropTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x0fRenameIndexItem\x12\x13\n\x0bsource_name\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_name\x18\x02 \x01(\t\x12\x1b\n\x13replace_destination\x18\x03 \x01(\x08\"\xbc\x08\n\x11\x41lterTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12*\n\x0b\x61\x64\x64_columns\x18\x03 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x14\n\x0c\x64rop_columns\x18\x04 \x03(\t\x12\x39\n\x10operation_params\x18\x05 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12,\n\ralter_columns\x18\x06 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x32\n\x10set_ttl_settings\x18\x07 \x01(\x0b\x32\x16.Ydb.Table.TtlSettingsH\x00\x12\x33\n\x11\x64rop_ttl_settings\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12*\n\x0b\x61\x64\x64_indexes\x18\t \x03(\x0b\x32\x15.Ydb.Table.TableIndex\x12\x14\n\x0c\x64rop_indexes\x18\n \x03(\t\x12:\n\x16\x61lter_storage_settings\x18\x0b \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x34\n\x13\x61\x64\x64_column_families\x18\x0c \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12\x36\n\x15\x61lter_column_families\x18\r \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12`\n\x10\x61lter_attributes\x18\x0e \x03(\x0b\x32\x31.Ydb.Table.AlterTableRequest.AlterAttributesEntryB\x13\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x03\x18\x80 \x12\x1d\n\x15set_compaction_policy\x18\x0f \x01(\t\x12\x44\n\x1b\x61lter_partitioning_settings\x18\x10 \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x35\n\x14set_key_bloom_filter\x18\x11 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x43\n\x1aset_read_replicas_settings\x18\x12 \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12.\n\x0f\x61\x64\x64_changefeeds\x18\x13 \x03(\x0b\x32\x15.Ydb.Table.Changefeed\x12\x18\n\x10\x64rop_changefeeds\x18\x14 \x03(\t\x12\x32\n\x0erename_indexes\x18\x15 \x03(\x0b\x32\x1a.Ydb.Table.RenameIndexItem\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nttl_action\"B\n\x12\x41lterTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x90\x01\n\x10\x43opyTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11\x43opyTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"T\n\rCopyTableItem\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x14\n\x0comit_indexes\x18\x03 \x01(\x08\"\x8c\x01\n\x11\x43opyTablesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12(\n\x06tables\x18\x03 \x03(\x0b\x32\x18.Ydb.Table.CopyTableItem\"B\n\x12\x43opyTablesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x0fRenameTableItem\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x1b\n\x13replace_destination\x18\x03 \x01(\x08\"\x90\x01\n\x13RenameTablesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12*\n\x06tables\x18\x03 \x03(\x0b\x32\x1a.Ydb.Table.RenameTableItem\"D\n\x14RenameTablesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xd3\x01\n\x14\x44\x65scribeTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12 \n\x18include_shard_key_bounds\x18\x05 \x01(\x08\x12\x1b\n\x13include_table_stats\x18\x06 \x01(\x08\x12\x1f\n\x17include_partition_stats\x18\x07 \x01(\x08\"E\n\x15\x44\x65scribeTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xfb\x05\n\x13\x44\x65scribeTableResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12&\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x03 \x03(\t\x12)\n\x10shard_key_bounds\x18\x04 \x03(\x0b\x32\x0f.Ydb.TypedValue\x12\x31\n\x07indexes\x18\x05 \x03(\x0b\x32 .Ydb.Table.TableIndexDescription\x12*\n\x0btable_stats\x18\x06 \x01(\x0b\x32\x15.Ydb.Table.TableStats\x12,\n\x0cttl_settings\x18\x07 \x01(\x0b\x32\x16.Ydb.Table.TtlSettings\x12\x34\n\x10storage_settings\x18\x08 \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x30\n\x0f\x63olumn_families\x18\t \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12\x42\n\nattributes\x18\n \x03(\x0b\x32..Ydb.Table.DescribeTableResult.AttributesEntry\x12>\n\x15partitioning_settings\x18\x0c \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x31\n\x10key_bloom_filter\x18\r \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12?\n\x16read_replicas_settings\x18\x0e \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12\x35\n\x0b\x63hangefeeds\x18\x0f \x03(\x0b\x32 .Ydb.Table.ChangefeedDescription\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x0b\x10\x0c\"2\n\x05Query\x12\x12\n\x08yql_text\x18\x01 \x01(\tH\x00\x12\x0c\n\x02id\x18\x02 \x01(\tH\x00\x42\x07\n\x05query\"\x1a\n\x18SerializableModeSettings\"6\n\x12OnlineModeSettings\x12 \n\x18\x61llow_inconsistent_reads\x18\x01 \x01(\x08\"\x13\n\x11StaleModeSettings\"\x16\n\x14SnapshotModeSettings\"\x9b\x02\n\x13TransactionSettings\x12\x46\n\x17serializable_read_write\x18\x01 \x01(\x0b\x32#.Ydb.Table.SerializableModeSettingsH\x00\x12\x39\n\x10online_read_only\x18\x02 \x01(\x0b\x32\x1d.Ydb.Table.OnlineModeSettingsH\x00\x12\x37\n\x0fstale_read_only\x18\x03 \x01(\x0b\x32\x1c.Ydb.Table.StaleModeSettingsH\x00\x12=\n\x12snapshot_read_only\x18\x04 \x01(\x0b\x32\x1f.Ydb.Table.SnapshotModeSettingsH\x00\x42\t\n\x07tx_mode\"{\n\x12TransactionControl\x12\x0f\n\x05tx_id\x18\x01 \x01(\tH\x00\x12\x32\n\x08\x62\x65gin_tx\x18\x02 \x01(\x0b\x32\x1e.Ydb.Table.TransactionSettingsH\x00\x12\x11\n\tcommit_tx\x18\n \x01(\x08\x42\r\n\x0btx_selector\")\n\x10QueryCachePolicy\x12\x15\n\rkeep_in_cache\x18\x01 \x01(\x08\"\xb1\x01\n\x14QueryStatsCollection\"\x98\x01\n\x04Mode\x12 \n\x1cSTATS_COLLECTION_UNSPECIFIED\x10\x00\x12\x19\n\x15STATS_COLLECTION_NONE\x10\x01\x12\x1a\n\x16STATS_COLLECTION_BASIC\x10\x02\x12\x19\n\x15STATS_COLLECTION_FULL\x10\x03\x12\x1c\n\x18STATS_COLLECTION_PROFILE\x10\x04\"\xbe\x03\n\x17\x45xecuteDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x31\n\ntx_control\x18\x02 \x01(\x0b\x32\x1d.Ydb.Table.TransactionControl\x12\x1f\n\x05query\x18\x03 \x01(\x0b\x32\x10.Ydb.Table.Query\x12\x46\n\nparameters\x18\x04 \x03(\x0b\x32\x32.Ydb.Table.ExecuteDataQueryRequest.ParametersEntry\x12\x37\n\x12query_cache_policy\x18\x05 \x01(\x0b\x32\x1b.Ydb.Table.QueryCachePolicy\x12\x39\n\x10operation_params\x18\x06 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\rcollect_stats\x18\x07 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"H\n\x18\x45xecuteDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"|\n\x19\x45xecuteSchemeQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"J\n\x1a\x45xecuteSchemeQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x1d\n\x0fTransactionMeta\x12\n\n\x02id\x18\x01 \x01(\t\"\x9f\x01\n\tQueryMeta\x12\n\n\x02id\x18\x01 \x01(\t\x12\x43\n\x10parameters_types\x18\x02 \x03(\x0b\x32).Ydb.Table.QueryMeta.ParametersTypesEntry\x1a\x41\n\x14ParametersTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Ydb.Type:\x02\x38\x01\"\xc1\x01\n\x12\x45xecuteQueryResult\x12#\n\x0bresult_sets\x18\x01 \x03(\x0b\x32\x0e.Ydb.ResultSet\x12+\n\x07tx_meta\x18\x02 \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\x12(\n\nquery_meta\x18\x03 \x01(\x0b\x32\x14.Ydb.Table.QueryMeta\x12/\n\x0bquery_stats\x18\x04 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"z\n\x17\x45xplainDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18\x45xplainDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\";\n\x12\x45xplainQueryResult\x12\x11\n\tquery_ast\x18\x01 \x01(\t\x12\x12\n\nquery_plan\x18\x02 \x01(\t\"z\n\x17PrepareDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18PrepareDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb7\x01\n\x12PrepareQueryResult\x12\x10\n\x08query_id\x18\x01 \x01(\t\x12L\n\x10parameters_types\x18\x02 \x03(\x0b\x32\x32.Ydb.Table.PrepareQueryResult.ParametersTypesEntry\x1a\x41\n\x14ParametersTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Ydb.Type:\x02\x38\x01\"a\n\x10KeepAliveRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11KeepAliveResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb7\x01\n\x0fKeepAliveResult\x12@\n\x0esession_status\x18\x01 \x01(\x0e\x32(.Ydb.Table.KeepAliveResult.SessionStatus\"b\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14SESSION_STATUS_READY\x10\x01\x12\x17\n\x13SESSION_STATUS_BUSY\x10\x02\"\x9d\x01\n\x17\x42\x65ginTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x33\n\x0btx_settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Table.TransactionSettings\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18\x42\x65ginTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"E\n\x16\x42\x65ginTransactionResult\x12+\n\x07tx_meta\x18\x01 \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\"\xb5\x01\n\x18\x43ommitTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\rcollect_stats\x18\x04 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\"I\n\x19\x43ommitTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"J\n\x17\x43ommitTransactionResult\x12/\n\x0bquery_stats\x18\x01 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"z\n\x1aRollbackTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"K\n\x1bRollbackTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x98\x01\n\x18StoragePolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06labels\x18\x02 \x03(\x0b\x32/.Ydb.Table.StoragePolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x1b\x43ompactionPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x06labels\x18\x02 \x03(\x0b\x32\x32.Ydb.Table.CompactionPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa2\x01\n\x1dPartitioningPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x06labels\x18\x02 \x03(\x0b\x32\x34.Ydb.Table.PartitioningPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x1a\x45xecutionPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.Ydb.Table.ExecutionPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\x1cReplicationPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x43\n\x06labels\x18\x02 \x03(\x0b\x32\x33.Ydb.Table.ReplicationPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n\x18\x43\x61\x63hingPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06labels\x18\x02 \x03(\x0b\x32/.Ydb.Table.CachingPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x04\n\x17TableProfileDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x06labels\x18\x02 \x03(\x0b\x32..Ydb.Table.TableProfileDescription.LabelsEntry\x12\x1e\n\x16\x64\x65\x66\x61ult_storage_policy\x18\x03 \x01(\t\x12 \n\x18\x61llowed_storage_policies\x18\x04 \x03(\t\x12!\n\x19\x64\x65\x66\x61ult_compaction_policy\x18\x05 \x01(\t\x12#\n\x1b\x61llowed_compaction_policies\x18\x06 \x03(\t\x12#\n\x1b\x64\x65\x66\x61ult_partitioning_policy\x18\x07 \x01(\t\x12%\n\x1d\x61llowed_partitioning_policies\x18\x08 \x03(\t\x12 \n\x18\x64\x65\x66\x61ult_execution_policy\x18\t \x01(\t\x12\"\n\x1a\x61llowed_execution_policies\x18\n \x03(\t\x12\"\n\x1a\x64\x65\x66\x61ult_replication_policy\x18\x0b \x01(\t\x12$\n\x1c\x61llowed_replication_policies\x18\x0c \x03(\t\x12\x1e\n\x16\x64\x65\x66\x61ult_caching_policy\x18\r \x01(\t\x12 \n\x18\x61llowed_caching_policies\x18\x0e \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"X\n\x1b\x44\x65scribeTableOptionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"L\n\x1c\x44\x65scribeTableOptionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x99\x04\n\x1a\x44\x65scribeTableOptionsResult\x12\x41\n\x15table_profile_presets\x18\x01 \x03(\x0b\x32\".Ydb.Table.TableProfileDescription\x12\x43\n\x16storage_policy_presets\x18\x02 \x03(\x0b\x32#.Ydb.Table.StoragePolicyDescription\x12I\n\x19\x63ompaction_policy_presets\x18\x03 \x03(\x0b\x32&.Ydb.Table.CompactionPolicyDescription\x12M\n\x1bpartitioning_policy_presets\x18\x04 \x03(\x0b\x32(.Ydb.Table.PartitioningPolicyDescription\x12G\n\x18\x65xecution_policy_presets\x18\x05 \x03(\x0b\x32%.Ydb.Table.ExecutionPolicyDescription\x12K\n\x1areplication_policy_presets\x18\x06 \x03(\x0b\x32\'.Ydb.Table.ReplicationPolicyDescription\x12\x43\n\x16\x63\x61\x63hing_policy_presets\x18\x07 \x03(\x0b\x32#.Ydb.Table.CachingPolicyDescription\"\xc0\x01\n\x08KeyRange\x12\"\n\x07greater\x18\x01 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12+\n\x10greater_or_equal\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12\x1f\n\x04less\x18\x03 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x01\x12(\n\rless_or_equal\x18\x04 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x01\x42\x0c\n\nfrom_boundB\n\n\x08to_bound\"\xc0\x01\n\x10ReadTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12&\n\tkey_range\x18\x03 \x01(\x0b\x32\x13.Ydb.Table.KeyRange\x12\x0f\n\x07\x63olumns\x18\x04 \x03(\t\x12\x0f\n\x07ordered\x18\x05 \x01(\x08\x12\x11\n\trow_limit\x18\x06 \x01(\x04\x12-\n\x0cuse_snapshot\x18\x07 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"\xbc\x01\n\x11ReadTableResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x08snapshot\x18\x04 \x01(\x0b\x32\x15.Ydb.VirtualTimestamp\x12*\n\x06result\x18\x03 \x01(\x0b\x32\x1a.Ydb.Table.ReadTableResult\"5\n\x0fReadTableResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\"\x8d\x02\n\x11\x42ulkUpsertRequest\x12\r\n\x05table\x18\x01 \x01(\t\x12\x1d\n\x04rows\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12?\n\x14\x61rrow_batch_settings\x18\x07 \x01(\x0b\x32\x1f.Ydb.Formats.ArrowBatchSettingsH\x00\x12\x30\n\x0c\x63sv_settings\x18\x08 \x01(\x0b\x32\x18.Ydb.Formats.CsvSettingsH\x00\x12\r\n\x04\x64\x61ta\x18\xe8\x07 \x01(\x0c\x42\r\n\x0b\x64\x61ta_format\"B\n\x12\x42ulkUpsertResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x42ulkUpsertResult\"\x91\x03\n\x17\x45xecuteScanQueryRequest\x12\x1f\n\x05query\x18\x03 \x01(\x0b\x32\x10.Ydb.Table.Query\x12\x46\n\nparameters\x18\x04 \x03(\x0b\x32\x32.Ydb.Table.ExecuteScanQueryRequest.ParametersEntry\x12\x35\n\x04mode\x18\x06 \x01(\x0e\x32\'.Ydb.Table.ExecuteScanQueryRequest.Mode\x12;\n\rcollect_stats\x18\x08 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"=\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x10\n\x0cMODE_EXPLAIN\x10\x01\x12\r\n\tMODE_EXEC\x10\x03J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08\"\xaf\x01\n\x1f\x45xecuteScanQueryPartialResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x38\n\x06result\x18\x03 \x01(\x0b\x32(.Ydb.Table.ExecuteScanQueryPartialResult\"\x8c\x01\n\x1d\x45xecuteScanQueryPartialResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12/\n\x0bquery_stats\x18\x06 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStatsJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\x42M\n\x0etech.ydb.tableZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Table\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_table_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016tech.ydb.tableZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Table\370\001\001'
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._options = None
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CREATETABLEREQUEST.fields_by_name['attributes']._options = None
  _CREATETABLEREQUEST.fields_by_name['attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 '
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._options = None
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._serialized_options = b'8\001'
  _ALTERTABLEREQUEST.fields_by_name['alter_attributes']._options = None
  _ALTERTABLEREQUEST.fields_by_name['alter_attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\003\030\200 '
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._options = None
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._options = None
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _QUERYMETA_PARAMETERSTYPESENTRY._options = None
  _QUERYMETA_PARAMETERSTYPESENTRY._serialized_options = b'8\001'
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._options = None
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._serialized_options = b'8\001'
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._options = None
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._options = None
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._options = None
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._options = None
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._options = None
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._options = None
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._options = None
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._options = None
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _CREATESESSIONREQUEST._serialized_start=389
  _CREATESESSIONREQUEST._serialized_end=470
  _CREATESESSIONRESPONSE._serialized_start=472
  _CREATESESSIONRESPONSE._serialized_end=541
  _CREATESESSIONRESULT._serialized_start=543
  _CREATESESSIONRESULT._serialized_end=584
  _DELETESESSIONREQUEST._serialized_start=586
  _DELETESESSIONREQUEST._serialized_end=687
  _DELETESESSIONRESPONSE._serialized_start=689
  _DELETESESSIONRESPONSE._serialized_end=758
  _GLOBALINDEX._serialized_start=760
  _GLOBALINDEX._serialized_end=773
  _GLOBALASYNCINDEX._serialized_start=775
  _GLOBALASYNCINDEX._serialized_end=793
  _TABLEINDEX._serialized_start=796
  _TABLEINDEX._serialized_end=982
  _TABLEINDEXDESCRIPTION._serialized_start=985
  _TABLEINDEXDESCRIPTION._serialized_end=1332
  _TABLEINDEXDESCRIPTION_STATUS._serialized_start=1253
  _TABLEINDEXDESCRIPTION_STATUS._serialized_end=1324
  _INDEXBUILDSTATE._serialized_start=1335
  _INDEXBUILDSTATE._serialized_end=1556
  _INDEXBUILDSTATE_STATE._serialized_start=1355
  _INDEXBUILDSTATE_STATE._serialized_end=1556
  _INDEXBUILDDESCRIPTION._serialized_start=1558
  _INDEXBUILDDESCRIPTION._serialized_end=1633
  _INDEXBUILDMETADATA._serialized_start=1636
  _INDEXBUILDMETADATA._serialized_end=1778
  _CHANGEFEEDMODE._serialized_start=1781
  _CHANGEFEEDMODE._serialized_end=1935
  _CHANGEFEEDMODE_MODE._serialized_start=1800
  _CHANGEFEEDMODE_MODE._serialized_end=1935
  _CHANGEFEEDFORMAT._serialized_start=1937
  _CHANGEFEEDFORMAT._serialized_end=2006
  _CHANGEFEEDFORMAT_FORMAT._serialized_start=1957
  _CHANGEFEEDFORMAT_FORMAT._serialized_end=2006
  _CHANGEFEED._serialized_start=2009
  _CHANGEFEED._serialized_end=2214
  _CHANGEFEEDDESCRIPTION._serialized_start=2217
  _CHANGEFEEDDESCRIPTION._serialized_end=2506
  _CHANGEFEEDDESCRIPTION_STATE._serialized_start=2437
  _CHANGEFEEDDESCRIPTION_STATE._serialized_end=2506
  _STORAGEPOOL._serialized_start=2508
  _STORAGEPOOL._serialized_end=2536
  _STORAGEPOLICY._serialized_start=2539
  _STORAGEPOLICY._serialized_end=2837
  _COLUMNFAMILYPOLICY._serialized_start=2840
  _COLUMNFAMILYPOLICY._serialized_end=3145
  _COLUMNFAMILYPOLICY_COMPRESSION._serialized_start=3069
  _COLUMNFAMILYPOLICY_COMPRESSION._serialized_end=3145
  _COMPACTIONPOLICY._serialized_start=3147
  _COMPACTIONPOLICY._serialized_end=3186
  _EXPLICITPARTITIONS._serialized_start=3188
  _EXPLICITPARTITIONS._serialized_end=3247
  _PARTITIONSTATS._serialized_start=3249
  _PARTITIONSTATS._serialized_end=3308
  _TABLESTATS._serialized_start=3311
  _TABLESTATS._serialized_end=3544
  _PARTITIONINGPOLICY._serialized_start=3547
  _PARTITIONINGPOLICY._serialized_end=3895
  _PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY._serialized_start=3763
  _PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY._serialized_end=3881
  _EXECUTIONPOLICY._serialized_start=3897
  _EXECUTIONPOLICY._serialized_end=3935
  _REPLICATIONPOLICY._serialized_start=3938
  _REPLICATIONPOLICY._serialized_end=4115
  _CACHINGPOLICY._serialized_start=4117
  _CACHINGPOLICY._serialized_end=4153
  _TABLEPROFILE._serialized_start=4156
  _TABLEPROFILE._serialized_end=4519
  _COLUMNMETA._serialized_start=4521
  _COLUMNMETA._serialized_end=4588
  _DATETYPECOLUMNMODESETTINGS._serialized_start=4590
  _DATETYPECOLUMNMODESETTINGS._serialized_end=4669
  _VALUESINCEUNIXEPOCHMODESETTINGS._serialized_start=4672
  _VALUESINCEUNIXEPOCHMODESETTINGS._serialized_end=4942
  _VALUESINCEUNIXEPOCHMODESETTINGS_UNIT._serialized_start=4828
  _VALUESINCEUNIXEPOCHMODESETTINGS_UNIT._serialized_end=4942
  _TTLSETTINGS._serialized_start=4945
  _TTLSETTINGS._serialized_end=5141
  _STORAGESETTINGS._serialized_start=5144
  _STORAGESETTINGS._serialized_end=5362
  _COLUMNFAMILY._serialized_start=5365
  _COLUMNFAMILY._serialized_end=5625
  _COLUMNFAMILY_COMPRESSION._serialized_start=5540
  _COLUMNFAMILY_COMPRESSION._serialized_end=5625
  _PARTITIONINGSETTINGS._serialized_start=5628
  _PARTITIONINGSETTINGS._serialized_end=5875
  _AZREADREPLICASSETTINGS._serialized_start=5877
  _AZREADREPLICASSETTINGS._serialized_end=5944
  _CLUSTERREPLICASSETTINGS._serialized_start=5946
  _CLUSTERREPLICASSETTINGS._serialized_end=6041
  _READREPLICASSETTINGS._serialized_start=6043
  _READREPLICASSETTINGS._serialized_end=6159
  _CREATETABLEREQUEST._serialized_start=6162
  _CREATETABLEREQUEST._serialized_end=7022
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._serialized_start=6959
  _CREATETABLEREQUEST_ATTRIBUTESENTRY._serialized_end=7008
  _CREATETABLERESPONSE._serialized_start=7024
  _CREATETABLERESPONSE._serialized_end=7091
  _DROPTABLEREQUEST._serialized_start=7093
  _DROPTABLEREQUEST._serialized_end=7210
  _DROPTABLERESPONSE._serialized_start=7212
  _DROPTABLERESPONSE._serialized_end=7277
  _RENAMEINDEXITEM._serialized_start=7279
  _RENAMEINDEXITEM._serialized_end=7372
  _ALTERTABLEREQUEST._serialized_start=7375
  _ALTERTABLEREQUEST._serialized_end=8459
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._serialized_start=8391
  _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._serialized_end=8445
  _ALTERTABLERESPONSE._serialized_start=8461
  _ALTERTABLERESPONSE._serialized_end=8527
  _COPYTABLEREQUEST._serialized_start=8530
  _COPYTABLEREQUEST._serialized_end=8674
  _COPYTABLERESPONSE._serialized_start=8676
  _COPYTABLERESPONSE._serialized_end=8741
  _COPYTABLEITEM._serialized_start=8743
  _COPYTABLEITEM._serialized_end=8827
  _COPYTABLESREQUEST._serialized_start=8830
  _COPYTABLESREQUEST._serialized_end=8970
  _COPYTABLESRESPONSE._serialized_start=8972
  _COPYTABLESRESPONSE._serialized_end=9038
  _RENAMETABLEITEM._serialized_start=9040
  _RENAMETABLEITEM._serialized_end=9133
  _RENAMETABLESREQUEST._serialized_start=9136
  _RENAMETABLESREQUEST._serialized_end=9280
  _RENAMETABLESRESPONSE._serialized_start=9282
  _RENAMETABLESRESPONSE._serialized_end=9350
  _DESCRIBETABLEREQUEST._serialized_start=9353
  _DESCRIBETABLEREQUEST._serialized_end=9564
  _DESCRIBETABLERESPONSE._serialized_start=9566
  _DESCRIBETABLERESPONSE._serialized_end=9635
  _DESCRIBETABLERESULT._serialized_start=9638
  _DESCRIBETABLERESULT._serialized_end=10401
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._serialized_start=6959
  _DESCRIBETABLERESULT_ATTRIBUTESENTRY._serialized_end=7008
  _QUERY._serialized_start=10403
  _QUERY._serialized_end=10453
  _SERIALIZABLEMODESETTINGS._serialized_start=10455
  _SERIALIZABLEMODESETTINGS._serialized_end=10481
  _ONLINEMODESETTINGS._serialized_start=10483
  _ONLINEMODESETTINGS._serialized_end=10537
  _STALEMODESETTINGS._serialized_start=10539
  _STALEMODESETTINGS._serialized_end=10558
  _SNAPSHOTMODESETTINGS._serialized_start=10560
  _SNAPSHOTMODESETTINGS._serialized_end=10582
  _TRANSACTIONSETTINGS._serialized_start=10585
  _TRANSACTIONSETTINGS._serialized_end=10868
  _TRANSACTIONCONTROL._serialized_start=10870
  _TRANSACTIONCONTROL._serialized_end=10993
  _QUERYCACHEPOLICY._serialized_start=10995
  _QUERYCACHEPOLICY._serialized_end=11036
  _QUERYSTATSCOLLECTION._serialized_start=11039
  _QUERYSTATSCOLLECTION._serialized_end=11216
  _QUERYSTATSCOLLECTION_MODE._serialized_start=11064
  _QUERYSTATSCOLLECTION_MODE._serialized_end=11216
  _EXECUTEDATAQUERYREQUEST._serialized_start=11219
  _EXECUTEDATAQUERYREQUEST._serialized_end=11665
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._serialized_start=11599
  _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._serialized_end=11665
  _EXECUTEDATAQUERYRESPONSE._serialized_start=11667
  _EXECUTEDATAQUERYRESPONSE._serialized_end=11739
  _EXECUTESCHEMEQUERYREQUEST._serialized_start=11741
  _EXECUTESCHEMEQUERYREQUEST._serialized_end=11865
  _EXECUTESCHEMEQUERYRESPONSE._serialized_start=11867
  _EXECUTESCHEMEQUERYRESPONSE._serialized_end=11941
  _TRANSACTIONMETA._serialized_start=11943
  _TRANSACTIONMETA._serialized_end=11972
  _QUERYMETA._serialized_start=11975
  _QUERYMETA._serialized_end=12134
  _QUERYMETA_PARAMETERSTYPESENTRY._serialized_start=12069
  _QUERYMETA_PARAMETERSTYPESENTRY._serialized_end=12134
  _EXECUTEQUERYRESULT._serialized_start=12137
  _EXECUTEQUERYRESULT._serialized_end=12330
  _EXPLAINDATAQUERYREQUEST._serialized_start=12332
  _EXPLAINDATAQUERYREQUEST._serialized_end=12454
  _EXPLAINDATAQUERYRESPONSE._serialized_start=12456
  _EXPLAINDATAQUERYRESPONSE._serialized_end=12528
  _EXPLAINQUERYRESULT._serialized_start=12530
  _EXPLAINQUERYRESULT._serialized_end=12589
  _PREPAREDATAQUERYREQUEST._serialized_start=12591
  _PREPAREDATAQUERYREQUEST._serialized_end=12713
  _PREPAREDATAQUERYRESPONSE._serialized_start=12715
  _PREPAREDATAQUERYRESPONSE._serialized_end=12787
  _PREPAREQUERYRESULT._serialized_start=12790
  _PREPAREQUERYRESULT._serialized_end=12973
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._serialized_start=12069
  _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._serialized_end=12134
  _KEEPALIVEREQUEST._serialized_start=12975
  _KEEPALIVEREQUEST._serialized_end=13072
  _KEEPALIVERESPONSE._serialized_start=13074
  _KEEPALIVERESPONSE._serialized_end=13139
  _KEEPALIVERESULT._serialized_start=13142
  _KEEPALIVERESULT._serialized_end=13325
  _KEEPALIVERESULT_SESSIONSTATUS._serialized_start=13227
  _KEEPALIVERESULT_SESSIONSTATUS._serialized_end=13325
  _BEGINTRANSACTIONREQUEST._serialized_start=13328
  _BEGINTRANSACTIONREQUEST._serialized_end=13485
  _BEGINTRANSACTIONRESPONSE._serialized_start=13487
  _BEGINTRANSACTIONRESPONSE._serialized_end=13559
  _BEGINTRANSACTIONRESULT._serialized_start=13561
  _BEGINTRANSACTIONRESULT._serialized_end=13630
  _COMMITTRANSACTIONREQUEST._serialized_start=13633
  _COMMITTRANSACTIONREQUEST._serialized_end=13814
  _COMMITTRANSACTIONRESPONSE._serialized_start=13816
  _COMMITTRANSACTIONRESPONSE._serialized_end=13889
  _COMMITTRANSACTIONRESULT._serialized_start=13891
  _COMMITTRANSACTIONRESULT._serialized_end=13965
  _ROLLBACKTRANSACTIONREQUEST._serialized_start=13967
  _ROLLBACKTRANSACTIONREQUEST._serialized_end=14089
  _ROLLBACKTRANSACTIONRESPONSE._serialized_start=14091
  _ROLLBACKTRANSACTIONRESPONSE._serialized_end=14166
  _STORAGEPOLICYDESCRIPTION._serialized_start=14169
  _STORAGEPOLICYDESCRIPTION._serialized_end=14321
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _STORAGEPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _COMPACTIONPOLICYDESCRIPTION._serialized_start=14324
  _COMPACTIONPOLICYDESCRIPTION._serialized_end=14482
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _PARTITIONINGPOLICYDESCRIPTION._serialized_start=14485
  _PARTITIONINGPOLICYDESCRIPTION._serialized_end=14647
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _EXECUTIONPOLICYDESCRIPTION._serialized_start=14650
  _EXECUTIONPOLICYDESCRIPTION._serialized_end=14806
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _REPLICATIONPOLICYDESCRIPTION._serialized_start=14809
  _REPLICATIONPOLICYDESCRIPTION._serialized_end=14969
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _CACHINGPOLICYDESCRIPTION._serialized_start=14972
  _CACHINGPOLICYDESCRIPTION._serialized_end=15124
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._serialized_start=14276
  _CACHINGPOLICYDESCRIPTION_LABELSENTRY._serialized_end=14321
  _TABLEPROFILEDESCRIPTION._serialized_start=15127
  _TABLEPROFILEDESCRIPTION._serialized_end=15701
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._serialized_start=14276
  _TABLEPROFILEDESCRIPTION_LABELSENTRY._serialized_end=14321
  _DESCRIBETABLEOPTIONSREQUEST._serialized_start=15703
  _DESCRIBETABLEOPTIONSREQUEST._serialized_end=15791
  _DESCRIBETABLEOPTIONSRESPONSE._serialized_start=15793
  _DESCRIBETABLEOPTIONSRESPONSE._serialized_end=15869
  _DESCRIBETABLEOPTIONSRESULT._serialized_start=15872
  _DESCRIBETABLEOPTIONSRESULT._serialized_end=16409
  _KEYRANGE._serialized_start=16412
  _KEYRANGE._serialized_end=16604
  _READTABLEREQUEST._serialized_start=16607
  _READTABLEREQUEST._serialized_end=16799
  _READTABLERESPONSE._serialized_start=16802
  _READTABLERESPONSE._serialized_end=16990
  _READTABLERESULT._serialized_start=16992
  _READTABLERESULT._serialized_end=17045
  _BULKUPSERTREQUEST._serialized_start=17048
  _BULKUPSERTREQUEST._serialized_end=17317
  _BULKUPSERTRESPONSE._serialized_start=17319
  _BULKUPSERTRESPONSE._serialized_end=17385
  _BULKUPSERTRESULT._serialized_start=17387
  _BULKUPSERTRESULT._serialized_end=17405
  _EXECUTESCANQUERYREQUEST._serialized_start=17408
  _EXECUTESCANQUERYREQUEST._serialized_end=17809
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._serialized_start=11599
  _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._serialized_end=11665
  _EXECUTESCANQUERYREQUEST_MODE._serialized_start=17724
  _EXECUTESCANQUERYREQUEST_MODE._serialized_end=17785
  _EXECUTESCANQUERYPARTIALRESPONSE._serialized_start=17812
  _EXECUTESCANQUERYPARTIALRESPONSE._serialized_end=17987
  _EXECUTESCANQUERYPARTIALRESULT._serialized_start=17990
  _EXECUTESCANQUERYPARTIALRESULT._serialized_end=18130
# @@protoc_insertion_point(module_scope)
