# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_scripting_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_scripting_pb2 as protos_dot_ydb__scripting__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ydb_scripting_v1.proto',
  package='Ydb.Scripting.V1',
  syntax='proto3',
  serialized_options=b'\n\025tech.ydb.scripting.v1Z8github.com/ydb-platform/ydb-go-genproto/Ydb_Scripting_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16ydb_scripting_v1.proto\x12\x10Ydb.Scripting.V1\x1a\x1aprotos/ydb_scripting.proto2\x9a\x02\n\x10ScriptingService\x12Q\n\nExecuteYql\x12 .Ydb.Scripting.ExecuteYqlRequest\x1a!.Ydb.Scripting.ExecuteYqlResponse\x12`\n\x10StreamExecuteYql\x12 .Ydb.Scripting.ExecuteYqlRequest\x1a(.Ydb.Scripting.ExecuteYqlPartialResponse0\x01\x12Q\n\nExplainYql\x12 .Ydb.Scripting.ExplainYqlRequest\x1a!.Ydb.Scripting.ExplainYqlResponseBQ\n\x15tech.ydb.scripting.v1Z8github.com/ydb-platform/ydb-go-genproto/Ydb_Scripting_V1b\x06proto3'
  ,
  dependencies=[protos_dot_ydb__scripting__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_SCRIPTINGSERVICE = _descriptor.ServiceDescriptor(
  name='ScriptingService',
  full_name='Ydb.Scripting.V1.ScriptingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=73,
  serialized_end=355,
  methods=[
  _descriptor.MethodDescriptor(
    name='ExecuteYql',
    full_name='Ydb.Scripting.V1.ScriptingService.ExecuteYql',
    index=0,
    containing_service=None,
    input_type=protos_dot_ydb__scripting__pb2._EXECUTEYQLREQUEST,
    output_type=protos_dot_ydb__scripting__pb2._EXECUTEYQLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamExecuteYql',
    full_name='Ydb.Scripting.V1.ScriptingService.StreamExecuteYql',
    index=1,
    containing_service=None,
    input_type=protos_dot_ydb__scripting__pb2._EXECUTEYQLREQUEST,
    output_type=protos_dot_ydb__scripting__pb2._EXECUTEYQLPARTIALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExplainYql',
    full_name='Ydb.Scripting.V1.ScriptingService.ExplainYql',
    index=2,
    containing_service=None,
    input_type=protos_dot_ydb__scripting__pb2._EXPLAINYQLREQUEST,
    output_type=protos_dot_ydb__scripting__pb2._EXPLAINYQLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCRIPTINGSERVICE)

DESCRIPTOR.services_by_name['ScriptingService'] = _SCRIPTINGSERVICE

# @@protoc_insertion_point(module_scope)
